@@ -5,7 +5,7 @@
 #
 from .config import Config
 
-version = "0.16.1"
+version = "0.18.0"
 
 
 class NS1:
@@ -223,6 +223,16 @@ class NS1:
 
         return ns1.rest.user.User(self.config)
 
+    def tsig(self):
+        """
+        Return a new raw REST interface to tsgi resources
+
+        :rtype: :py:class:`ns1.rest.tsig.Tsgi`
+        """
+        import ns1.rest.tsig
+
+        return ns1.rest.tsig.Tsig(self.config)
+
     def apikey(self):
         """
         Return a new raw REST interface to API key resources
@@ -233,6 +243,56 @@ class NS1:
 
         return ns1.rest.apikey.APIKey(self.config)
 
+    def acls(self):
+        """
+        Return a new raw REST interface to ACL resources
+
+        :rtype: :py:class:`ns1.rest.acls.Acls`
+        """
+        import ns1.rest.acls
+
+        return ns1.rest.acls.Acls(self.config)
+
+    def views(self):
+        """
+        Return a new raw REST interface to View resources
+
+        :rtype: :py:class:`ns1.rest.views.Views`
+        """
+        import ns1.rest.views
+
+        return ns1.rest.views.Views(self.config)
+
+    def client_classes(self):
+        """
+        Return a new raw REST interface to Client Classes resources
+
+        :rtype: :py:class:`ns1.rest.client_classes.ClientClasses`
+        """
+        import ns1.rest.client_classes
+
+        return ns1.rest.client_classes.ClientClasses(self.config)
+
+    def dhcp_option_spaces(self):
+        """
+        Return a new raw REST interface to DHCP Option Spaces resources
+
+        :rtype: :py:class:`ns1.rest.dhcp_option_spaces.DHCOptionSpaces`
+        """
+        import ns1.rest.dhcp_option_spaces
+
+        return ns1.rest.dhcp_option_spaces.DHCPOptionSpaces(self.config)
+
+    def pools(self):
+        """
+        Return a new raw REST interface to Pools resources
+
+        :rtype: :py:class:`ns1.rest.pools.Pools`
+        """
+        import ns1.rest.pools
+
+        return ns1.rest.pools.Pools(self.config)
+
     # HIGH LEVEL INTERFACE
     def loadZone(self, zone, callback=None, errback=None):
         """
@@ -248,16 +308,28 @@ class NS1:
         return zone.load(callback=callback, errback=errback)
 
     def searchZone(
-        self, zone, q=None, has_geo=False, callback=None, errback=None
+        self,
+        query,
+        type="all",
+        expand=True,
+        max=None,
+        callback=None,
+        errback=None,
     ):
         """
-        Search a zone for a given search query (e.g., for geological data, etc)
+        This method was updated since NS1 deprecated v1/search/zones
+        Search a zone record or answers for a given search query (e.g., for geological data, etc)
 
-        :param zone: NOT a string like loadZone - an already loaded ns1.zones.Zone, like one returned from loadZone
-        :return:
+        :param query: query to search zone name or other type name
+        :param type: String Filters search results by type. Enum: "zone", "record", "all", "answers"
+        :param expand: Boolean Expands contents of search results.
+        :param max: Integer Maximum number of search results to display
+        :return: list of zones searched
         """
+        from ns1.rest.zones import Zones
 
-        return zone.search(q, has_geo, callback=callback, errback=errback)
+        rest_zone = Zones(self.config)
+        return rest_zone.search(query, type, expand, max, callback, errback)
 
     def createZone(
         self, zone, zoneFile=None, callback=None, errback=None, **kwargs
